@@ -160,9 +160,11 @@ Bool setup_window_structure(
 void setup_window_name(FvwmWindow *tmp_win)
 {
   XTextProperty text_prop;
+#ifdef I18N_MB
+  char **list;
+  int num;
 
   if ( XGetWMName(dpy, tmp_win->w, &text_prop) != 0 )
-#ifdef I18N_MB
   {
     if (text_prop.value)
     {
@@ -199,6 +201,7 @@ void setup_window_name(FvwmWindow *tmp_win)
     }
   }
 #else
+  if ( XGetWMName(dpy, tmp_win->w, &text_prop) != 0 )
     tmp_win->name = (char *)text_prop.value;
 #endif
   else
@@ -1587,13 +1590,19 @@ void GetWindowSizeHints(FvwmWindow *tmp)
   if (tmp->hints.flags & PResizeInc)
   {
     SET_SIZE_INC_SET(tmp, 1);
-    if (tmp->hints.width_inc <= 0)
+    if (tmp->hints.width_inc < 0 ||
+        (tmp->hints.width_inc == 0 &&
+         (tmp->hints.flags & PMinSize) && (tmp->hints.flags & PMaxSize) &&
+         tmp->hints.min_width != tmp->hints.max_width))
     {
       tmp->hints.width_inc = 1;
       broken_cause = "width_inc";
       SET_SIZE_INC_SET(tmp, 0);
     }
-    if (tmp->hints.height_inc <= 0)
+    if (tmp->hints.height_inc < 0 ||
+        (tmp->hints.height_inc == 0 &&
+         (tmp->hints.flags & PMinSize) && (tmp->hints.flags & PMaxSize) &&
+         tmp->hints.min_height != tmp->hints.max_height))
     {
       tmp->hints.height_inc = 1;
       if (!*broken_cause)
