@@ -37,6 +37,7 @@
 #include "libs/fvwmlib.h"
 #include "fvwm.h"
 #include "externs.h"
+#include "events.h"
 #include "cursor.h"
 #include "functions.h"
 #include "bindings.h"
@@ -1093,7 +1094,7 @@ void SetupTitleBar(FvwmWindow *tmp_win, int w, int h)
 
 static void get_common_decorations(
   common_decorations_type *cd, FvwmWindow *t, draw_window_parts draw_parts,
-  Bool has_focus, int force, Window expose_win)
+  Bool has_focus, int force, Window expose_win, Bool is_border)
 {
   color_quad *draw_colors;
 
@@ -1106,7 +1107,8 @@ static void get_common_decorations(
       cd->texture_pixmap = GetDecor(t, BorderStyle.active.u.p->picture);
     }
     cd->back_pixmap= Scr.gray_pixmap;
-    draw_colors = &(t->hicolors);
+    if (is_border) draw_colors = &(t->border_hicolors);
+    else draw_colors = &(t->hicolors);
   }
   else
   {
@@ -1119,7 +1121,8 @@ static void get_common_decorations(
       cd->back_pixmap = Scr.sticky_gray_pixmap;
     else
     cd->back_pixmap = Scr.light_gray_pixmap;
-    draw_colors = &(t->colors);
+    if (is_border) draw_colors = &(t->border_colors);
+    else draw_colors = &(t->colors);
   }
   cd->fore_color = draw_colors->fore;
   cd->back_color = draw_colors->back;
@@ -1248,24 +1251,28 @@ void DrawDecorations(
   }
 
   get_common_decorations(
-    &cd, t, draw_parts, has_focus, force, expose_win);
+    &cd, t, draw_parts, has_focus, force, expose_win, FALSE);
 
-  if (cd.flags.has_color_changed)
+  if (cd.flags.has_color_changed && HAS_TITLE(t))
   {
-    change_window_background(t->decor_w, cd.valuemask, &cd.attributes);
-    if (HAS_TITLE(t))
-    {
-      change_window_background(
-	t->title_w, cd.notex_valuemask, &cd.notex_attributes);
-    }
+    change_window_background(
+      t->title_w, cd.notex_valuemask, &cd.notex_attributes);
   }
 
-  if ((draw_parts & DRAW_FRAME) && is_frame_redraw_allowed)
-    RedrawBorder(&cd, t, has_focus, force, expose_win);
   if ((draw_parts & DRAW_BUTTONS) && HAS_TITLE(t) && is_button_redraw_allowed)
     RedrawButtons(&cd, t, has_focus, force, expose_win);
   if ((draw_parts & DRAW_TITLE) && HAS_TITLE(t) && is_title_redraw_allowed)
     RedrawTitle(&cd, t, has_focus);
+  get_common_decorations(
+    &cd, t, draw_parts, has_focus, force, expose_win, TRUE);
+  if (cd.flags.has_color_changed ||
+      ((draw_parts & DRAW_FRAME) && (is_frame_redraw_allowed)))
+  {
+    get_common_decorations(
+      &cd, t, draw_parts, has_focus, force, expose_win, TRUE);
+    change_window_background(t->decor_w, cd.valuemask, &cd.attributes);
+    RedrawBorder(&cd, t, has_focus, force, expose_win);
+  }
 
   /* Sync to make the change look fast! */
   XSync(dpy,0);
@@ -1299,7 +1306,6 @@ void DrawDecorations(
 void SetupFrame(
   FvwmWindow *tmp_win, int x, int y, int w, int h, Bool sendEvent)
 {
-  XEvent client_event;
   XWindowChanges xwc;
   unsigned long xwcm;
   int i;
@@ -1591,38 +1597,10 @@ void SetupFrame(
    * look at their current geometry */
   if (sendEvent && !shaded)
   {
-    client_event.type = ConfigureNotify;
-    client_event.xconfigure.display = dpy;
-    client_event.xconfigure.event = tmp_win->w;
-    client_event.xconfigure.window = tmp_win->w;
-
-    client_event.xconfigure.x = x + tmp_win->boundary_width;
-    client_event.xconfigure.y =
-      y + ((HAS_BOTTOM_TITLE(tmp_win)) ? 0 : tmp_win->title_g.height) +
-      tmp_win->boundary_width;
-    client_event.xconfigure.width = w-2*tmp_win->boundary_width;
-    client_event.xconfigure.height =h-2*tmp_win->boundary_width -
-      tmp_win->title_g.height;
-
-    client_event.xconfigure.border_width = 0;
-    /* Real ConfigureNotify events say we're above title window, so ... */
-    /* what if we don't have a title ????? */
-    client_event.xconfigure.above = tmp_win->frame;
-    client_event.xconfigure.override_redirect = False;
-    XSendEvent(dpy, tmp_win->w, False, StructureNotifyMask, &client_event);
+    SendConfigureNotify(tmp_win, x, y, w, h, 0, True);
 #ifdef FVWM_DEBUG_MSGS
     fvwm_msg(DBG,"SetupFrame","Sent ConfigureNotify (w == %d, h == %d)",
              client_event.xconfigure.width,client_event.xconfigure.height);
-#endif
-#if 1
-    /* This is for buggy tk, which waits for the real ConfigureNotify
-       on frame instead of the synthetic one on w. The geometry data
-       in the event will not be correct for the frame, but tk doesn't
-       look at that data anyway. */
-    client_event.xconfigure.event = tmp_win->frame;
-    client_event.xconfigure.window = tmp_win->frame;
-
-    XSendEvent(dpy, tmp_win->frame, False,StructureNotifyMask,&client_event);
 #endif
   }
 
