@@ -33,6 +33,7 @@
 
 #include "libs/fvwmlib.h"
 #include "fvwm.h"
+#include "externs.h"
 #include "cursor.h"
 #include "functions.h"
 #include "bindings.h"
@@ -62,6 +63,13 @@ static void DoSetFocus(Window w, FvwmWindow *Fw, Bool FocusByMouse, Bool NoWarp)
     DrawDecorations(Fw, DRAW_ALL, False, False, None);
     return;
   }
+  if (Fw && !IS_LENIENT(Fw) &&
+      Fw->wmhints && (Fw->wmhints->flags & InputHint) && !Fw->wmhints->input &&
+      Scr.Focus && Scr.Focus->Desk == Scr.CurrentDesk)
+  {
+    /* window doesn't want focus */
+    return;
+  }
 
   /* ClickToFocus focus queue manipulation - only performed for
    * Focus-by-mouse type focus events */
@@ -158,7 +166,8 @@ static void DoSetFocus(Window w, FvwmWindow *Fw, Bool FocusByMouse, Bool NoWarp)
       the newly-focused window is ungrabbed in events.c (HandleButtonPress).
   */
   if ((Scr.Ungrabbed != NULL)&&
-      (HAS_CLICK_FOCUS(Scr.Ungrabbed) || Scr.go.MouseFocusClickRaises) &&
+      (HAS_CLICK_FOCUS(Scr.Ungrabbed) ||
+       DO_RAISE_MOUSE_FOCUS_CLICK(Scr.Ungrabbed)) &&
       (Scr.Ungrabbed != Fw))
     {
       /* need to grab all buttons for window that we are about to
