@@ -952,7 +952,9 @@ void SetRCDefaults(void)
     "AddToMenu MenuFvwmRoot \"Builtin Menu\" Title",
     "+ \"&1. XTerm\" Exec xterm",
     "+ \"&2. Setup Form\" Module FvwmForm FormFvwmSetup.",
-    "+ \"&3. Issue FVWM commands\" Module FvwmConsole",
+    "+ \"&3. Setup 95 Script\" Module FvwmScript ScriptFvwmSetup95",
+    "+ \"&4. Issue FVWM commands\" Module FvwmConsole",
+    "+ \"&R. Restart FVWM\" Restart",
     "+ \"&X. Exit FVWM\" Quit",
     "Mouse 0 R N Popup MenuFvwmRoot",
     "Read "FVWM_CONFIGDIR"/ConfigFvwmDefaults",
