@@ -61,11 +61,10 @@ int *readPipes;
 int *writePipes;
 int *pipeOn;
 char **pipeName;
-/*  RBW - hack for gsfr new config args  */
-unsigned long junkzero = 0;
 
 unsigned long *PipeMask;
 unsigned long *SyncMask;
+unsigned long *NoGrabMask;
 struct queue_buff_struct **pipeQueue;
 
 extern fd_set init_fdset;
@@ -84,6 +83,7 @@ void initModules(void)
   pipeOn = (int *)safemalloc(sizeof(int)*npipes);
   PipeMask = (unsigned long *)safemalloc(sizeof(unsigned long)*npipes);
   SyncMask = (unsigned long *)safemalloc(sizeof(unsigned long)*npipes);
+  NoGrabMask = (unsigned long *)safemalloc(sizeof(unsigned long)*npipes);
   pipeName = (char **)safemalloc(sizeof(char *)*npipes);
   pipeQueue=(struct queue_buff_struct **)
     safemalloc(sizeof(struct queue_buff_struct *)*npipes);
@@ -95,6 +95,7 @@ void initModules(void)
       pipeOn[i] = -1;
       PipeMask[i] = MAX_MASK;
       SyncMask[i] = 0;
+      NoGrabMask[i] = 0;
       pipeQueue[i] = (struct queue_buff_struct *)NULL;
       pipeName[i] = NULL;
     }
@@ -262,6 +263,7 @@ static int do_execute_module(F_CMD_ARGS, Bool desperate)
       pipeOn[i] = -1;
       PipeMask[i] = MAX_MASK;
       SyncMask[i] = 0;
+      NoGrabMask[i] = 0;
       free(arg1);
       pipeQueue[i] = NULL;
       if (DoingCommandLine) {
@@ -928,11 +930,8 @@ static void BroadcastNewPacket(unsigned long event_type,
             &(*(_t))->frame_g.height,\
 	    (unsigned long)(sizeof(unsigned long)),\
             &(*(_t))->Desk,\
- \
-/* RBW - temp hack to preserve old alignment */ \
 	    (unsigned long)(sizeof(unsigned long)),\
-            (void *) &junkzero,\
- \
+            &(*(_t))->layer,\
 	    (unsigned long)(sizeof(unsigned long)),\
             &(*(_t))->title_g.height,\
 	    (unsigned long)(sizeof(unsigned long)),\
@@ -1190,7 +1189,7 @@ int PositiveWrite(int module, unsigned long *ptr, int size)
   /* would be better to send RecaptureStart and RecaptureEnd messages. */
   /* If module is lock on send for iconify message and its an
    * iconify event and server grabbed, then return */
-  if ((SyncMask[module] & M_ICONIFY & ptr[1]) && (myxgrabcount != 0))
+  if ((NoGrabMask[module] & SyncMask[module] & ptr[1]) && (myxgrabcount != 0))
   {
     return -1;
   }
@@ -1468,3 +1467,11 @@ void setSyncMaskFunc(F_CMD_ARGS)
   GetIntegerArguments(action, NULL, &val, 1);
   SyncMask[*Module] = (unsigned long)val;
 }
+
+void setNoGrabMaskFunc(F_CMD_ARGS)
+{
+  int val = 0;
+
+  GetIntegerArguments(action, NULL, &val, 1);
+  NoGrabMask[*Module] = (unsigned long)val;
+}
