@@ -85,7 +85,7 @@ static Pixel fore_pix;
 static Window main_win;
 static Window app_win;
 
-#define MW_EVENTS   (ExposureMask | ButtonReleaseMask | KeyReleaseMask)
+static EventMask mw_events = ExposureMask | ButtonReleaseMask | KeyReleaseMask;
 
 static Atom wm_del_win;
 
@@ -97,7 +97,7 @@ static int ListSize=0;
 static struct Item* itemlistRoot = NULL;
 static int max_col1, max_col2;
 static char id[15], desktop[10], swidth[10], sheight[10], borderw[10];
-static char geometry[30], mymin_aspect[11], max_aspect[11];
+static char geometry[30], mymin_aspect[11], max_aspect[11], layer[10];
 
 /***********************************************************************
  *
@@ -299,6 +299,7 @@ struct ConfigWinPacket  *cfgpacket = (void *) body;
       target.frame_w = body[5];
       target.frame_h = body[6];
       target.desktop = body[7];
+      target.layer = body[8];
 /*      target.flags = body[8];  */
       memcpy(&target.flags, &(cfgpacket->flags), sizeof(cfgpacket->flags));
       target.title_h = body[9];
@@ -424,13 +425,12 @@ void list_end(void)
   /* size and create the window */
   lmax = max_col1 + max_col2 + 15;
 
-  height = ListSize*(font->ascent + font->descent);
+  height = ListSize * (font->ascent + font->descent);
 
   mysizehints.flags=
     USSize|USPosition|PWinGravity|PResizeInc|PBaseSize|PMinSize|PMaxSize;
-  /* subtract one for the right/bottom border */
-  mysizehints.width = lmax+10;
-  mysizehints.height=height+10;
+  mysizehints.width = lmax + 10;
+  mysizehints.height= height + 10;
   mysizehints.width_inc = 1;
   mysizehints.height_inc = 1;
   mysizehints.base_height = mysizehints.height;
@@ -474,7 +474,7 @@ void list_end(void)
 
   attributes.colormap = Pcmap;
   attributes.border_pixel = 0;
-  main_win = XCreateWindow(dpy, Root, mysizehints.x, mysizehints.y,
+  main_win = XCreateWindow(dpy, Root, x, y,
 			   mysizehints.width, mysizehints.height, 0, Pdepth,
 			   InputOutput, Pvisual,
 			   CWColormap | CWBackPixel | CWBorderPixel,
@@ -483,7 +483,10 @@ void list_end(void)
   XSetWMProtocols(dpy,main_win,&wm_del_win,1);
 
   XSetWMNormalHints(dpy,main_win,&mysizehints);
-  XSelectInput(dpy,main_win,MW_EVENTS);
+  /* have to ask for configure events when transparent */
+  if (colorset >= 0 && Colorset[colorset].pixmap == ParentRelative)
+    mw_events |= StructureNotifyMask;
+  XSelectInput(dpy, main_win, mw_events);
   change_window_name(&MyName[1]);
 
   gcm = GCForeground|GCFont;
@@ -513,9 +516,8 @@ void list_end(void)
       XNextEvent(dpy,&Event);
       switch(Event.type) {
         case Expose:
-	  if(Event.xexpose.count == 0)
-	    RedrawWindow();
-	  XFlush(dpy);
+          while (XCheckTypedEvent(dpy, Expose, &Event)) ;
+	  RedrawWindow();
 	  break;
         case KeyRelease:
         case ButtonRelease:
@@ -523,8 +525,31 @@ void list_end(void)
         case ClientMessage:
 	  if (Event.xclient.format==32 && Event.xclient.data.l[0]==wm_del_win)
 	    exit(0);
-        default:
+	case ConfigureNotify:
+	{
+	  /* this only happens with transparent windows, slurp up as many
+	   * events as possible before redrawing to reduce flickering */
+	  XEvent event;
+	  while (XCheckTypedEvent(dpy, ConfigureNotify, &event))
+	  {
+	    if (!event.xconfigure.send_event)
+	      continue;
+            Event.xconfigure.x = event.xconfigure.x;
+            Event.xconfigure.y = event.xconfigure.y;
+            Event.xconfigure.send_event = True;
+	  }
+	  /* only refresh if moved */
+	  if (x != Event.xconfigure.x || y != Event.xconfigure.y)
+	  {
+	    x = Event.xconfigure.x;
+	    y = Event.xconfigure.y;
+	    /* flush any expose events */
+	    while (XCheckTypedEvent(dpy, Expose, &Event)) ;
+	    XClearWindow(dpy, main_win);
+	    RedrawWindow();
+	  }
 	  break;
+	}
       }
     }
 
@@ -547,6 +572,12 @@ void list_end(void)
 				mysizehints.height,
 				&Colorset[colorset], Pdepth, gc,
 				True);
+	    /* ask for movement events iff transparent */
+	    if (Colorset[colorset].pixmap == ParentRelative)
+	      mw_events |= StructureNotifyMask;
+	    else
+	      mw_events &= ~StructureNotifyMask;
+	    XSelectInput(dpy, main_win, mw_events);
 	  }
 	}
 	free(token);
@@ -660,6 +691,7 @@ void MakeList(void)
   height = target.frame_h - target.title_h - bw;
 
   sprintf(desktop, "%ld",  target.desktop);
+  sprintf(layer,   "%ld",  target.layer);
   sprintf(id,      "0x%x", (unsigned int)target.id);
   sprintf(swidth,  "%d",   width);
   sprintf(sheight, "%d",   height);
@@ -673,6 +705,7 @@ void MakeList(void)
   AddToList("Resource:",      target.res);
   AddToList("Window ID:",     id);
   AddToList("Desk:",          desktop);
+  AddToList("Layer:",         layer);
   AddToList("Width:",         swidth);
   AddToList("Height:",        sheight);
   AddToList("X (current page):",   xstr);
@@ -680,14 +713,6 @@ void MakeList(void)
   AddToList("Boundary Width:", borderw);
 
   AddToList("Sticky:",        (IS_STICKY(targ)    ? yes : no));
-/*
-    RBW - not sure how to translate ONTOP into layer terms yet...
-    I think we'd need to see the default_layer field from the FvwmWindow,
-    and that's not broadcast currently.
-    But, then, it's been removed from the display...I suppose for the same
-    reason.
-*/
-/*  AddToList("Ontop:",         (target.flags & ONTOP  	? yes : no));  */
   AddToList("NoTitle:",       (HAS_TITLE(targ)    ? no : yes));
   AddToList("Iconified:",     (IS_ICONIFIED(targ) ? yes : no));
   AddToList("Transient:",     (IS_TRANSIENT(targ) ? yes : no));
@@ -764,24 +789,6 @@ void MakeList(void)
   strcat(geometry, loc);
   AddToList("Geometry:", geometry);
 
-#if 0
-  {
-    char tmp[20], *foo;
-    sprintf(tmp,"%d", target.base_w);
-    foo = strdup(tmp);
-    AddToList("  - base_w:", foo);
-    sprintf(tmp,"%d", target.width_inc);
-    foo = strdup(tmp);
-    AddToList("  - width_inc:", foo);
-    sprintf(tmp,"%d", target.base_h);
-    foo = strdup(tmp);
-    AddToList("  - base_h:", foo);
-    sprintf(tmp,"%d", target.height_inc);
-    foo = strdup(tmp);
-    AddToList("  - height_inc:", foo);
-  }
-#endif
-
   {
     Atom *protocols = NULL, *ap;
     Atom _XA_WM_TAKE_FOCUS = XInternAtom(dpy, "WM_TAKE_FOCUS", False);
