@@ -134,6 +134,8 @@ Window		icon_win;               /* icon window */
 static char *GetBalloonLabel(const PagerWindow *pw,const char *fmt);
 extern void ExitPager(void);
 
+static Pixmap default_pixmap = None;
+
 /***********************************************************************
  *
  *  Procedure:
@@ -149,7 +151,7 @@ void initialize_viz_pager(void)
     Scr.Pager_w = Scr.Root;
     Scr.NormalGC = DefaultGC(dpy, Scr.screen);
   } else {
-    attr.background_pixmap = ParentRelative;
+    attr.background_pixmap = None;
     attr.border_pixel = 0;
     attr.colormap = Pcmap;
     Scr.Pager_w = XCreateWindow(dpy, Scr.Root, -10, -10, 10, 10, 0, Pdepth,
@@ -160,6 +162,10 @@ void initialize_viz_pager(void)
   xgcv.plane_mask = AllPlanes;
   Scr.MiniIconGC = XCreateGC(dpy, Scr.Pager_w, GCPlaneMask, &xgcv);
   Scr.black = GetColor("Black");
+
+  /* Transparent background are only allowed when the depth matched the root */
+  if (Pdepth == DefaultDepth(dpy, Scr.screen))
+    default_pixmap = ParentRelative;
 }
 
 /***********************************************************************
@@ -425,7 +431,7 @@ void initialize_pager(void)
     sizehints.flags |= USPosition;
 
   valuemask = (CWBackPixmap | CWBorderPixel | CWColormap | CWEventMask);
-  attributes.background_pixmap = ParentRelative;
+  attributes.background_pixmap = default_pixmap;
   attributes.border_pixel = fore_pix;
   attributes.colormap = Pcmap;
   attributes.event_mask = (StructureNotifyMask);
@@ -558,14 +564,14 @@ void initialize_pager(void)
 
     /* create the hilight desk title drawing GC */
     if ((Pdepth < 2) || (fore_pix == hi_pix))
-      gcv.foreground = (Desks[i].colorset < 0) ? back_pix
-	: Colorset[Desks[i].colorset].bg;
+      gcv.foreground = (Desks[i].highcolorset < 0) ? back_pix
+	: Colorset[Desks[i].highcolorset].fg;
     else
-      gcv.foreground = (Desks[i].colorset < 0) ? fore_pix
-	: Colorset[Desks[i].colorset].fg;
+      gcv.foreground = (Desks[i].highcolorset < 0) ? fore_pix
+	: Colorset[Desks[i].highcolorset].fg;
     Desks[i].rvGC = XCreateGC(dpy, Scr.Pager_w, GCForeground | GCFont, &gcv);
 
-    /* create the vrtual page boundary GC */
+    /* create the virtual page boundary GC */
     gcv.foreground = (Desks[i].colorset < 0) ? fore_pix
       : Colorset[Desks[i].colorset].fg;
     gcv.line_style = (use_dashed_separators) ? LineOnOffDash : LineSolid;
@@ -2849,19 +2855,25 @@ void change_colorset(int colorset)
   if (colorset < 0)
     return;
 
-  XSetWindowBackgroundPixmap(dpy, Scr.Pager_w, ParentRelative);
+  XSetWindowBackgroundPixmap(dpy, Scr.Pager_w, default_pixmap);
   for(i=0;i<ndesks;i++)
   {
     if (Desks[i].highcolorset == colorset)
     {
       XSetForeground(dpy, Desks[i].HiliteGC,Colorset[colorset].bg);
       XSetForeground(dpy, Desks[i].rvGC, Colorset[colorset].fg);
-
       if (HilightDesks)
       {
+	if (uselabel && (i == Scr.CurrentDesk))
+	{
+	  SetWindowBackground(dpy, Desks[i].title_w, 0, 0,
+			      &Colorset[colorset], Pdepth,
+			      Scr.NormalGC, True);
+	} 
         SetWindowBackground(dpy, Desks[i].CPagerWin, 0, 0,
 			    &Colorset[colorset], Pdepth,
 			    Scr.NormalGC, True);
+
         XLowerWindow(dpy,Desks[i].CPagerWin);
       }
 
@@ -2870,9 +2882,15 @@ void change_colorset(int colorset)
     if (Desks[i].colorset == colorset)
     {
       attributes.border_pixel = Colorset[colorset].fg;
-      XSetWindowBackgroundPixmap(dpy, Desks[i].title_w, ParentRelative);
+      XSetWindowBackgroundPixmap(dpy, Desks[i].title_w, default_pixmap);
       XClearArea(dpy, Desks[i].title_w, 0, 0, 0, 0, True);
       XChangeWindowAttributes(dpy,Desks[i].w, CWBorderPixel, &attributes);
+      if (uselabel)
+      {
+	SetWindowBackground(dpy, Desks[i].title_w, 0, 0,
+			    &Colorset[colorset], Pdepth,
+			    Scr.NormalGC, True);
+      }
       SetWindowBackground(dpy, Desks[i].w, 0, 0,
 			  &Colorset[colorset], Pdepth,
 			  Scr.NormalGC, True);
@@ -2880,7 +2898,12 @@ void change_colorset(int colorset)
       XSetForeground(dpy, Desks[i].NormalGC,Colorset[colorset].fg);
       XSetForeground(dpy, Desks[i].DashedGC,Colorset[colorset].fg);
 
-    }
+    } 
+    else if (Desks[i].highcolorset == colorset && uselabel)
+      SetWindowBackground(dpy, Desks[i].title_w, 0, 0,
+			  &Colorset[Desks[i].colorset], Pdepth,
+			  Scr.NormalGC, True);
+
 
     if (ShowBalloons && Desks[i].ballooncolorset == colorset)
     {
